torchelie.optim
===============

.. autoclass:: torchelie.optim.Lookahead
   :members:
   :undoc-members:

.. autoclass:: torchelie.optim.RAdamW
   :members:

.. autoclass:: torchelie.optim.DeepDreamOptim
   :members:

.. autoclass:: torchelie.optim.AddSign
   :members:

torchelie.lr_scheduler
======================

.. automodule:: torchelie.lr_scheduler
   :members:
   :undoc-members:

